Class: Aws::SecurityIR::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::SecurityIR::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-securityir/client.rb,
sig/client.rbs
Overview
An API client for SecurityIR. To construct a client, you need to configure a :region and :credentials.
client = Aws::SecurityIR::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _BatchGetMemberAccountDetailsResponseSuccess, _CancelMembershipResponseSuccess, _CloseCaseResponseSuccess, _CreateCaseCommentResponseSuccess, _CreateCaseResponseSuccess, _CreateMembershipResponseSuccess, _GetCaseAttachmentDownloadUrlResponseSuccess, _GetCaseAttachmentUploadUrlResponseSuccess, _GetCaseResponseSuccess, _GetMembershipResponseSuccess, _ListCaseEditsResponseSuccess, _ListCasesResponseSuccess, _ListCommentsResponseSuccess, _ListInvestigationsResponseSuccess, _ListMembershipsResponseSuccess, _ListTagsForResourceResponseSuccess, _SendFeedbackResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateCaseCommentResponseSuccess, _UpdateCaseResponseSuccess, _UpdateCaseStatusResponseSuccess, _UpdateMembershipResponseSuccess, _UpdateResolverTypeResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_get_member_account_details(params = {}) ⇒ Types::BatchGetMemberAccountDetailsResponse
Provides information on whether the supplied account IDs are associated with a membership.
-
#cancel_membership(params = {}) ⇒ Types::CancelMembershipResponse
Cancels an existing membership.
-
#close_case(params = {}) ⇒ Types::CloseCaseResponse
Closes an existing case.
-
#create_case(params = {}) ⇒ Types::CreateCaseResponse
Creates a new case.
-
#create_case_comment(params = {}) ⇒ Types::CreateCaseCommentResponse
Adds a comment to an existing case.
-
#create_membership(params = {}) ⇒ Types::CreateMembershipResponse
Creates a new membership.
-
#get_case(params = {}) ⇒ Types::GetCaseResponse
Returns the attributes of a case.
-
#get_case_attachment_download_url(params = {}) ⇒ Types::GetCaseAttachmentDownloadUrlResponse
Returns a Pre-Signed URL for uploading attachments into a case.
-
#get_case_attachment_upload_url(params = {}) ⇒ Types::GetCaseAttachmentUploadUrlResponse
Uploads an attachment to a case.
-
#get_membership(params = {}) ⇒ Types::GetMembershipResponse
Returns the attributes of a membership.
-
#list_case_edits(params = {}) ⇒ Types::ListCaseEditsResponse
Views the case history for edits made to a designated case.
-
#list_cases(params = {}) ⇒ Types::ListCasesResponse
Lists all cases the requester has access to.
-
#list_comments(params = {}) ⇒ Types::ListCommentsResponse
Returns comments for a designated case.
-
#list_investigations(params = {}) ⇒ Types::ListInvestigationsResponse
Investigation performed by an agent for a security incident...
-
#list_memberships(params = {}) ⇒ Types::ListMembershipsResponse
Returns the memberships that the calling principal can access.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Returns currently configured tags on a resource.
-
#send_feedback(params = {}) ⇒ Struct
Send feedback based on response investigation action.
-
#tag_resource(params = {}) ⇒ Struct
Adds a tag(s) to a designated resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes a tag(s) from a designate resource.
-
#update_case(params = {}) ⇒ Struct
Updates an existing case.
-
#update_case_comment(params = {}) ⇒ Types::UpdateCaseCommentResponse
Updates an existing case comment.
-
#update_case_status(params = {}) ⇒ Types::UpdateCaseStatusResponse
Updates the state transitions for a designated cases.
-
#update_membership(params = {}) ⇒ Struct
Updates membership configuration.
-
#update_resolver_type(params = {}) ⇒ Types::UpdateResolverTypeResponse
Updates the resolver type for a case.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-securityir/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2401 2402 2403 |
# File 'lib/aws-sdk-securityir/client.rb', line 2401 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2404 2405 2406 |
# File 'lib/aws-sdk-securityir/client.rb', line 2404 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#batch_get_member_account_details(params = {}) ⇒ Types::BatchGetMemberAccountDetailsResponse
Provides information on whether the supplied account IDs are associated with a membership.
123123123 which is nine digits,
and with zero-prepend would be 000123123123. Not zero-prepending to
12 digits could result in errors.
87 |
# File 'sig/client.rbs', line 87
def batch_get_member_account_details: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2374 2375 2376 2377 2378 2379 2380 2381 2382 2383 2384 2385 2386 2387 2388 2389 2390 |
# File 'lib/aws-sdk-securityir/client.rb', line 2374 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::SecurityIR') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-securityir' context[:gem_version] = '1.26.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_membership(params = {}) ⇒ Types::CancelMembershipResponse
Cancels an existing membership.
98 |
# File 'sig/client.rbs', line 98
def cancel_membership: (
|
#close_case(params = {}) ⇒ Types::CloseCaseResponse
Closes an existing case.
109 |
# File 'sig/client.rbs', line 109
def close_case: (
|
#create_case(params = {}) ⇒ Types::CreateCaseResponse
Creates a new case.
119 |
# File 'sig/client.rbs', line 119
def create_case: (
|
#create_case_comment(params = {}) ⇒ Types::CreateCaseCommentResponse
Adds a comment to an existing case.
155 |
# File 'sig/client.rbs', line 155
def create_case_comment: (
|
#create_membership(params = {}) ⇒ Types::CreateMembershipResponse
Creates a new membership.
167 |
# File 'sig/client.rbs', line 167
def create_membership: (
|
#get_case(params = {}) ⇒ Types::GetCaseResponse
Returns the attributes of a case.
213 |
# File 'sig/client.rbs', line 213
def get_case: (
|
#get_case_attachment_download_url(params = {}) ⇒ Types::GetCaseAttachmentDownloadUrlResponse
Returns a Pre-Signed URL for uploading attachments into a case.
223 |
# File 'sig/client.rbs', line 223
def get_case_attachment_download_url: (
|
#get_case_attachment_upload_url(params = {}) ⇒ Types::GetCaseAttachmentUploadUrlResponse
Uploads an attachment to a case.
234 |
# File 'sig/client.rbs', line 234
def get_case_attachment_upload_url: (
|
#get_membership(params = {}) ⇒ Types::GetMembershipResponse
Returns the attributes of a membership.
259 |
# File 'sig/client.rbs', line 259
def get_membership: (
|
#list_case_edits(params = {}) ⇒ Types::ListCaseEditsResponse
Views the case history for edits made to a designated case.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
271 |
# File 'sig/client.rbs', line 271
def list_case_edits: (
|
#list_cases(params = {}) ⇒ Types::ListCasesResponse
Lists all cases the requester has access to.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
285 |
# File 'sig/client.rbs', line 285
def list_cases: (
|
#list_comments(params = {}) ⇒ Types::ListCommentsResponse
Returns comments for a designated case.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
298 |
# File 'sig/client.rbs', line 298
def list_comments: (
|
#list_investigations(params = {}) ⇒ Types::ListInvestigationsResponse
Investigation performed by an agent for a security incident...
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
311 |
# File 'sig/client.rbs', line 311
def list_investigations: (
|
#list_memberships(params = {}) ⇒ Types::ListMembershipsResponse
Returns the memberships that the calling principal can access.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
324 |
# File 'sig/client.rbs', line 324
def list_memberships: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Returns currently configured tags on a resource.
335 |
# File 'sig/client.rbs', line 335
def list_tags_for_resource: (
|
#send_feedback(params = {}) ⇒ Struct
Send feedback based on response investigation action
344 |
# File 'sig/client.rbs', line 344
def send_feedback: (
|
#tag_resource(params = {}) ⇒ Struct
Adds a tag(s) to a designated resource.
356 |
# File 'sig/client.rbs', line 356
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes a tag(s) from a designate resource.
366 |
# File 'sig/client.rbs', line 366
def untag_resource: (
|
#update_case(params = {}) ⇒ Struct
Updates an existing case.
376 |
# File 'sig/client.rbs', line 376
def update_case: (
|
#update_case_comment(params = {}) ⇒ Types::UpdateCaseCommentResponse
Updates an existing case comment.
438 |
# File 'sig/client.rbs', line 438
def update_case_comment: (
|
#update_case_status(params = {}) ⇒ Types::UpdateCaseStatusResponse
Updates the state transitions for a designated cases.
Self-managed: the following states are available for self-managed cases.
-
Submitted → Detection and Analysis
-
Detection and Analysis → Containment, Eradication, and Recovery
-
Detection and Analysis → Post-incident Activities
-
Containment, Eradication, and Recovery → Detection and Analysis
-
Containment, Eradication, and Recovery → Post-incident Activities
-
Post-incident Activities → Containment, Eradication, and Recovery
-
Post-incident Activities → Detection and Analysis
-
Any → Closed
AWS supported: You must use the CloseCase API to close.
450 |
# File 'sig/client.rbs', line 450
def update_case_status: (
|
#update_membership(params = {}) ⇒ Struct
Updates membership configuration.
460 |
# File 'sig/client.rbs', line 460
def update_membership: (
|
#update_resolver_type(params = {}) ⇒ Types::UpdateResolverTypeResponse
Updates the resolver type for a case.
This is a one-way action and cannot be reversed.
493 |
# File 'sig/client.rbs', line 493
def update_resolver_type: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2394 2395 2396 |
# File 'lib/aws-sdk-securityir/client.rb', line 2394 def waiter_names [] end |