Class: Aws::SecurityIR::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::SecurityIR::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-securityir/client.rb
Overview
An API client for SecurityIR. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::SecurityIR::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_get_member_account_details(params = {}) ⇒ Types::BatchGetMemberAccountDetailsResponse
Provides information on whether the supplied account IDs are associated with a membership.
-
#cancel_membership(params = {}) ⇒ Types::CancelMembershipResponse
Cancels an existing membership.
-
#close_case(params = {}) ⇒ Types::CloseCaseResponse
Closes an existing case.
-
#create_case(params = {}) ⇒ Types::CreateCaseResponse
Creates a new case.
-
#create_case_comment(params = {}) ⇒ Types::CreateCaseCommentResponse
Adds a comment to an existing case.
-
#create_membership(params = {}) ⇒ Types::CreateMembershipResponse
Creates a new membership.
-
#get_case(params = {}) ⇒ Types::GetCaseResponse
Returns the attributes of a case.
-
#get_case_attachment_download_url(params = {}) ⇒ Types::GetCaseAttachmentDownloadUrlResponse
Returns a Pre-Signed URL for uploading attachments into a case.
-
#get_case_attachment_upload_url(params = {}) ⇒ Types::GetCaseAttachmentUploadUrlResponse
Uploads an attachment to a case.
-
#get_membership(params = {}) ⇒ Types::GetMembershipResponse
Returns the attributes of a membership.
-
#list_case_edits(params = {}) ⇒ Types::ListCaseEditsResponse
Views the case history for edits made to a designated case.
-
#list_cases(params = {}) ⇒ Types::ListCasesResponse
Lists all cases the requester has access to.
-
#list_comments(params = {}) ⇒ Types::ListCommentsResponse
Returns comments for a designated case.
-
#list_investigations(params = {}) ⇒ Types::ListInvestigationsResponse
Investigation performed by an agent for a security incident…
-
#list_memberships(params = {}) ⇒ Types::ListMembershipsResponse
Returns the memberships that the calling principal can access.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Returns currently configured tags on a resource.
-
#send_feedback(params = {}) ⇒ Struct
Send feedback based on response investigation action.
-
#tag_resource(params = {}) ⇒ Struct
Adds a tag(s) to a designated resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes a tag(s) from a designate resource.
-
#update_case(params = {}) ⇒ Struct
Updates an existing case.
-
#update_case_comment(params = {}) ⇒ Types::UpdateCaseCommentResponse
Updates an existing case comment.
-
#update_case_status(params = {}) ⇒ Types::UpdateCaseStatusResponse
Updates the state transitions for a designated cases.
-
#update_membership(params = {}) ⇒ Struct
Updates membership configuration.
-
#update_resolver_type(params = {}) ⇒ Types::UpdateResolverTypeResponse
Updates the resolver type for a case.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-securityir/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2401 2402 2403 |
# File 'lib/aws-sdk-securityir/client.rb', line 2401 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2404 2405 2406 |
# File 'lib/aws-sdk-securityir/client.rb', line 2404 def errors_module Errors end |
Instance Method Details
#batch_get_member_account_details(params = {}) ⇒ Types::BatchGetMemberAccountDetailsResponse
Provides information on whether the supplied account IDs are associated with a membership.
<note markdown=“1”> AWS account ID’s may appear less than 12 characters and need to be zero-prepended. An example would be ‘123123123` which is nine digits, and with zero-prepend would be `000123123123`. Not zero-prepending to 12 digits could result in errors.
</note>
550 551 552 553 |
# File 'lib/aws-sdk-securityir/client.rb', line 550 def batch_get_member_account_details(params = {}, = {}) req = build_request(:batch_get_member_account_details, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2374 2375 2376 2377 2378 2379 2380 2381 2382 2383 2384 2385 2386 2387 2388 2389 2390 |
# File 'lib/aws-sdk-securityir/client.rb', line 2374 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::SecurityIR') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-securityir' context[:gem_version] = '1.24.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_membership(params = {}) ⇒ Types::CancelMembershipResponse
Cancels an existing membership.
591 592 593 594 |
# File 'lib/aws-sdk-securityir/client.rb', line 591 def cancel_membership(params = {}, = {}) req = build_request(:cancel_membership, params) req.send_request() end |
#close_case(params = {}) ⇒ Types::CloseCaseResponse
Closes an existing case.
635 636 637 638 |
# File 'lib/aws-sdk-securityir/client.rb', line 635 def close_case(params = {}, = {}) req = build_request(:close_case, params) req.send_request() end |
#create_case(params = {}) ⇒ Types::CreateCaseResponse
Creates a new case.
796 797 798 799 |
# File 'lib/aws-sdk-securityir/client.rb', line 796 def create_case(params = {}, = {}) req = build_request(:create_case, params) req.send_request() end |
#create_case_comment(params = {}) ⇒ Types::CreateCaseCommentResponse
Adds a comment to an existing case.
856 857 858 859 |
# File 'lib/aws-sdk-securityir/client.rb', line 856 def create_case_comment(params = {}, = {}) req = build_request(:create_case_comment, params) req.send_request() end |
#create_membership(params = {}) ⇒ Types::CreateMembershipResponse
Creates a new membership.
975 976 977 978 |
# File 'lib/aws-sdk-securityir/client.rb', line 975 def create_membership(params = {}, = {}) req = build_request(:create_membership, params) req.send_request() end |
#get_case(params = {}) ⇒ Types::GetCaseResponse
Returns the attributes of a case.
1109 1110 1111 1112 |
# File 'lib/aws-sdk-securityir/client.rb', line 1109 def get_case(params = {}, = {}) req = build_request(:get_case, params) req.send_request() end |
#get_case_attachment_download_url(params = {}) ⇒ Types::GetCaseAttachmentDownloadUrlResponse
Returns a Pre-Signed URL for uploading attachments into a case.
1156 1157 1158 1159 |
# File 'lib/aws-sdk-securityir/client.rb', line 1156 def (params = {}, = {}) req = build_request(:get_case_attachment_download_url, params) req.send_request() end |
#get_case_attachment_upload_url(params = {}) ⇒ Types::GetCaseAttachmentUploadUrlResponse
Uploads an attachment to a case.
1222 1223 1224 1225 |
# File 'lib/aws-sdk-securityir/client.rb', line 1222 def (params = {}, = {}) req = build_request(:get_case_attachment_upload_url, params) req.send_request() end |
#get_membership(params = {}) ⇒ Types::GetMembershipResponse
Returns the attributes of a membership.
1323 1324 1325 1326 |
# File 'lib/aws-sdk-securityir/client.rb', line 1323 def get_membership(params = {}, = {}) req = build_request(:get_membership, params) req.send_request() end |
#list_case_edits(params = {}) ⇒ Types::ListCaseEditsResponse
Views the case history for edits made to a designated case.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1393 1394 1395 1396 |
# File 'lib/aws-sdk-securityir/client.rb', line 1393 def list_case_edits(params = {}, = {}) req = build_request(:list_case_edits, params) req.send_request() end |
#list_cases(params = {}) ⇒ Types::ListCasesResponse
Lists all cases the requester has access to.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1468 1469 1470 1471 |
# File 'lib/aws-sdk-securityir/client.rb', line 1468 def list_cases(params = {}, = {}) req = build_request(:list_cases, params) req.send_request() end |
#list_comments(params = {}) ⇒ Types::ListCommentsResponse
Returns comments for a designated case.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1536 1537 1538 1539 |
# File 'lib/aws-sdk-securityir/client.rb', line 1536 def list_comments(params = {}, = {}) req = build_request(:list_comments, params) req.send_request() end |
#list_investigations(params = {}) ⇒ Types::ListInvestigationsResponse
Investigation performed by an agent for a security incident…
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1614 1615 1616 1617 |
# File 'lib/aws-sdk-securityir/client.rb', line 1614 def list_investigations(params = {}, = {}) req = build_request(:list_investigations, params) req.send_request() end |
#list_memberships(params = {}) ⇒ Types::ListMembershipsResponse
Returns the memberships that the calling principal can access.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1677 1678 1679 1680 |
# File 'lib/aws-sdk-securityir/client.rb', line 1677 def list_memberships(params = {}, = {}) req = build_request(:list_memberships, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Returns currently configured tags on a resource.
1722 1723 1724 1725 |
# File 'lib/aws-sdk-securityir/client.rb', line 1722 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#send_feedback(params = {}) ⇒ Struct
Send feedback based on response investigation action
1783 1784 1785 1786 |
# File 'lib/aws-sdk-securityir/client.rb', line 1783 def send_feedback(params = {}, = {}) req = build_request(:send_feedback, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds a tag(s) to a designated resource.
1828 1829 1830 1831 |
# File 'lib/aws-sdk-securityir/client.rb', line 1828 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes a tag(s) from a designate resource.
1865 1866 1867 1868 |
# File 'lib/aws-sdk-securityir/client.rb', line 1865 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_case(params = {}) ⇒ Struct
Updates an existing case.
2080 2081 2082 2083 |
# File 'lib/aws-sdk-securityir/client.rb', line 2080 def update_case(params = {}, = {}) req = build_request(:update_case, params) req.send_request() end |
#update_case_comment(params = {}) ⇒ Types::UpdateCaseCommentResponse
Updates an existing case comment.
2136 2137 2138 2139 |
# File 'lib/aws-sdk-securityir/client.rb', line 2136 def update_case_comment(params = {}, = {}) req = build_request(:update_case_comment, params) req.send_request() end |
#update_case_status(params = {}) ⇒ Types::UpdateCaseStatusResponse
Updates the state transitions for a designated cases.
Self-managed: the following states are available for self-managed cases.
-
Submitted → Detection and Analysis
-
Detection and Analysis → Containment, Eradication, and Recovery
-
Detection and Analysis → Post-incident Activities
-
Containment, Eradication, and Recovery → Detection and Analysis
-
Containment, Eradication, and Recovery → Post-incident Activities
-
Post-incident Activities → Containment, Eradication, and Recovery
-
Post-incident Activities → Detection and Analysis
-
Any → Closed
**AWS supported**: You must use the ‘CloseCase` API to close.
2204 2205 2206 2207 |
# File 'lib/aws-sdk-securityir/client.rb', line 2204 def update_case_status(params = {}, = {}) req = build_request(:update_case_status, params) req.send_request() end |
#update_membership(params = {}) ⇒ Struct
Updates membership configuration.
2311 2312 2313 2314 |
# File 'lib/aws-sdk-securityir/client.rb', line 2311 def update_membership(params = {}, = {}) req = build_request(:update_membership, params) req.send_request() end |
#update_resolver_type(params = {}) ⇒ Types::UpdateResolverTypeResponse
Updates the resolver type for a case.
This is a one-way action and cannot be reversed.
2365 2366 2367 2368 |
# File 'lib/aws-sdk-securityir/client.rb', line 2365 def update_resolver_type(params = {}, = {}) req = build_request(:update_resolver_type, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2394 2395 2396 |
# File 'lib/aws-sdk-securityir/client.rb', line 2394 def waiter_names [] end |